@@ -5,7 +5,9 @@ import scipy.io
 
 
 def read_10X_multi(matrix_dir: str):
-    
+    r"""
+    matrix_dir: downloaded from 10x website, containing matrix.mtx.gz, barcodes.tsv.gz and features.tsv.gz
+    """
     mat_path = os.path.join(matrix_dir, "matrix.mtx.gz")
     mat = scipy.io.mmread(mat_path)
 
